==> kubernetes-model-1.0.36-sources.jar: io/fabric8/kubernetes/api/model/EnvVarFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class EnvVarFluentImpl<T extends EnvVarFluent<T>> extends BaseFluent<T> implements EnvVarFluent<T>{

     String name;     String value;     VisitableBuilder<EnvVarSource, ?> valueFrom;     Map<String, Object> additionalProperties = new HashMap();
public EnvVarFluentImpl(){
    
}
public EnvVarFluentImpl( EnvVar instance ){
    this.withName(instance.getName()); this.withValue(instance.getValue()); this.withValueFrom(instance.getValueFrom()); 
}

    public String getName(){
    return this.name;
    }
    public T withName( String name){
    this.name=name; return (T) this;
    }
    public String getValue(){
    return this.value;
    }
    public T withValue( String value){
    this.value=value; return (T) this;
    }
    public EnvVarSource getValueFrom(){
    return this.valueFrom!=null?this.valueFrom.build():null;
    }
    public T withValueFrom( EnvVarSource valueFrom){
    if (valueFrom!=null){ this.valueFrom= new EnvVarSourceBuilder(valueFrom); _visitables.add(this.valueFrom);} return (T) this;
    }
    public ValueFromNested<T> withNewValueFrom(){
    return new ValueFromNestedImpl<T>();
    }
    public ValueFromNested<T> withNewValueFromLike( EnvVarSource item){
    return new ValueFromNestedImpl<T>(item);
    }
    public ValueFromNested<T> editValueFrom(){
    return withNewValueFromLike(getValueFrom());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
EnvVarFluentImpl that = (EnvVarFluentImpl) o;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
if (value != null ? !value.equals(that.value) :that.value != null) return false;
if (valueFrom != null ? !valueFrom.equals(that.valueFrom) :that.valueFrom != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class ValueFromNestedImpl<N> extends EnvVarSourceFluentImpl<ValueFromNested<N>> implements ValueFromNested<N>{

        private final EnvVarSourceBuilder builder;
    
             ValueFromNestedImpl (){
        this.builder = new EnvVarSourceBuilder(this);
        }
             ValueFromNestedImpl ( EnvVarSource item){
        this.builder = new EnvVarSourceBuilder(this, item);
        }
    
            public N endValueFrom(){
            return and();
        }
            public N and(){
            return (N) EnvVarFluentImpl.this.withValueFrom(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.47-sources.jar: io/fabric8/kubernetes/api/model/EnvVarFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;

public class EnvVarFluentImpl<T extends EnvVarFluent<T>> extends BaseFluent<T> implements EnvVarFluent<T>{

     String name;     String value;     VisitableBuilder<EnvVarSource, ?> valueFrom;     Map<String, Object> additionalProperties = new HashMap();
public EnvVarFluentImpl(){
    
}
public EnvVarFluentImpl( EnvVar instance ){
    this.withName(instance.getName()); this.withValue(instance.getValue()); this.withValueFrom(instance.getValueFrom()); 
}

    public String getName(){
    return this.name;
    }
    public T withName( String name){
    this.name=name; return (T) this;
    }
    public String getValue(){
    return this.value;
    }
    public T withValue( String value){
    this.value=value; return (T) this;
    }
    public EnvVarSource getValueFrom(){
    return this.valueFrom!=null?this.valueFrom.build():null;
    }
    public T withValueFrom( EnvVarSource valueFrom){
    if (valueFrom!=null){ this.valueFrom= new EnvVarSourceBuilder(valueFrom); _visitables.add(this.valueFrom);} return (T) this;
    }
    public ValueFromNested<T> withNewValueFrom(){
    return new ValueFromNestedImpl<T>();
    }
    public ValueFromNested<T> withNewValueFromLike( EnvVarSource item){
    return new ValueFromNestedImpl<T>(item);
    }
    public ValueFromNested<T> editValueFrom(){
    return withNewValueFromLike(getValueFrom());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
EnvVarFluentImpl that = (EnvVarFluentImpl) o;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
if (value != null ? !value.equals(that.value) :that.value != null) return false;
if (valueFrom != null ? !valueFrom.equals(that.valueFrom) :that.valueFrom != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class ValueFromNestedImpl<N> extends EnvVarSourceFluentImpl<ValueFromNested<N>> implements ValueFromNested<N>{

        private final EnvVarSourceBuilder builder;
    
             ValueFromNestedImpl (){
        this.builder = new EnvVarSourceBuilder(this);
        }
             ValueFromNestedImpl ( EnvVarSource item){
        this.builder = new EnvVarSourceBuilder(this, item);
        }
    
            public N endValueFrom(){
            return and();
        }
            public N and(){
            return (N) EnvVarFluentImpl.this.withValueFrom(builder.build());
        }
    
}


}
